@@ -579,6 +579,15 @@ on_needle_changed (BjbController *self)
 }
 
 
+/* Return FALSE to end timeout, see below on_manager_changed */
+static gboolean
+bjb_controller_set_window_active (BjbController *self)
+{
+  bjb_window_base_set_active (self->priv->window, TRUE);
+  return FALSE;
+}
+
+
 /* Depending on the change at data level,
  * the view has to be totaly refreshed or just amended */
 static void
@@ -595,7 +604,6 @@ on_manager_changed (BijiManager            *manager,
 
 
 
-
   if (group != self->priv->group)
   {
     g_debug ("Controller received signal for group %i while %i",
@@ -646,13 +654,23 @@ on_manager_changed (BijiManager            *manager,
         gtk_list_store_remove (GTK_LIST_STORE (priv->model), p_iter);
 
       priv->items_to_show = g_list_remove (priv->items_to_show, item);
-      notify_displayed_items_changed (self);
+      if (priv->items_to_show == NULL)
+        bjb_window_base_switch_to (self->priv->window, BJB_WINDOW_BASE_NO_NOTE);
+
+      else
+        notify_displayed_items_changed (self);
+
       break;
 
+    /* Apply the needle to display the relevant items.
+     * The window will ping to tell it's now active
+     * Use another thread for this, because controller is now up to date,
+     * and we need to unlock mutex,
+     * since activating window can call this function! */
     default:
       bjb_controller_apply_needle (self);
       if (flag == BIJI_MANAGER_MASS_CHANGE)
-        bjb_window_base_set_active (self->priv->window, TRUE);
+        g_timeout_add (1, (GSourceFunc) bjb_controller_set_window_active, self);
   }
 
   g_mutex_unlock (&priv->mutex);
